@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: UploadItemListReader.h 2564 2007-10-10 14:08:20Z svn $
  *****************************************************************************/
 
 #ifndef UPOLOAD_ITEM_LIST_READER_H
@@ -54,17 +54,19 @@ public:
      * @param[in] pool プール
      * @param[in] data_dir_path アイテムが保存されているディレクトリ
      * @param[in] thumb_dir_path サムネイルが保存されているディレクトリ
-     * @param[in] shm 共有メモリ
-     * @param[in] thumbnail_list サムネイルのリスト
      * @param[in] max_file_size リストの最大合計ファイルサイズ
      * @param[in] max_list_size リストの最大サイズ
+     * @param[in] shm 共有メモリ
+     * @param[in] thumbnail_list サムネイルのリスト
+     * @param[in] mtime 最終修正日時
      * @return 掲示板のアップロードアイテム
      */
     static UploadItemList *read(apr_pool_t *pool, const char *data_dir_path,
-                                const char *thumb_dir_path, apr_shm_t *shm,
-                                ThumbnailList *thumbnail_list,
+                                const char *thumb_dir_path,
                                 apr_uint64_t max_file_size,
-                                apr_size_t max_list_size);
+                                apr_size_t max_list_size,
+                                apr_shm_t *shm, ThumbnailList *thumbnail_list,
+                                apr_time_t *mtime);
 
 private:
     UploadItemListReader();
