@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2508 2007-07-06 22:47:18Z svn $
+ * $Id: UploadItemManager.h 2568 2007-10-11 15:47:19Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -44,20 +44,15 @@ class ThumbnailList;
 class ThumbnailIterator;
 
 /**
- * @brief BBS のスレッドを管理するクラス．
+ * @brief アップロードアイテムを管理するクラス．
+ * 排他処理を行います．
  *
- * 更新日時の新しい MGR_ON_MEMORY_ITEM_COUNT 個のスレッドの内容をメモリ上で
- * 管理します.
+ * リストの変更(追加/削除)および最終更新日時の取得はこのクラスを利用し
+ * て行います．
  */
 class UploadItemManager: public Uncopyable
 {
 public:
-    /**
-     * 初期化を行います．
-     *
-     * @param[in] item_list スレッドのリスト
-     */
-    void init(UploadItemList *item_list, ThumbnailList *thumbnail_list);
     apr_size_t add(apr_pool_t *pool,
                    const char *file_name, const char *file_mime,
                    apr_uint64_t file_size, const char *file_digest,
@@ -80,12 +75,18 @@ public:
      * @param[in] data_dir_path アイテムが保存されているディレクトリ
      * @param[in] file_dir_path ファイルが保存されているディレクトリ
      * @param[in] thumb_dir_path サムネイルが保存されているディレクトリ
+     * @param[in] item_list アイテムのリスト
+     * @param[in] thumbnail_list サムネイルのリスト
+     * @param[in] mtime 最終更新日時
      * @return UploadItemManager のインスタンス
      */
     static UploadItemManager *get_instance(apr_shm_t *shm, apr_pool_t *pool,
                                            const char *data_dir_path,
                                            const char *file_dir_path,
-                                           const char *thumb_dir_path);
+                                           const char *thumb_dir_path,
+                                           UploadItemList *item_list,
+                                           ThumbnailList *thumbnail_list,
+                                           apr_time_t mtime);
     /**
      * メモリ上にあるアイテムデータをディスクに書き出します．
      *
@@ -101,9 +102,8 @@ public:
      * @param[in] thumbnail_list サムネイルのリスト
      * @return UploadItemManager のインスタンス
      */
-    static UploadItemManager *child_init(apr_shm_t *shm,
-                                         UploadItemList *item_list,
-                                         ThumbnailList *thumbnail_list);
+    void child_init(apr_shm_t *shm, UploadItemList *item_list,
+                    ThumbnailList *thumbnail_list);
     /**
      * マネージャのデータの最大サイズを計算します．
      *
@@ -124,8 +124,10 @@ private:
     /** 書き込み時，一度に同期する数． */
     static const apr_size_t SYNC_LIMIT;
 
-    UploadItemManager(apr_pool_t *pool, const char *data_dir_path,
-                      const char *file_dir_path, const char *thumb_dir_path);
+    UploadItemManager(apr_shm_t *shm, apr_pool_t *pool,
+                      const char *data_dir_path, const char *file_dir_path,
+                      const char *thumb_dir_path, UploadItemList *item_list,
+                      ThumbnailList *thumbnail_list, apr_time_t mtime);
     apr_size_t add_impl(apr_pool_t *pool,
                         const char *file_name, const char *file_mime,
                         apr_uint64_t file_size, const char *file_digest,
@@ -134,26 +136,6 @@ private:
                         const char *ip_address);
     void remove_impl(apr_pool_t *pool, UploadItem *uitem);
 
-    /**
-     * 子プロセス用の初期化を行います．
-     *
-     * @param[in] item_list スレッドのリスト
-     * @param[in] thumbnail_list サムネイルのリスト
-     */
-    void child_init_impl(UploadItemList *item_list,
-                         ThumbnailList *thumbnail_list);
-    /**
-     * 共有メモリをクリアします．
-     */
-    void clear_shm();
-    /**
-     * 共有メモリを初期化します．
-     */
-    void init_shm();
-    /**
-     * 共有メモリを子プロセス用に初期化します．
-     */
-    void attach_shm();
     /**
      * ユニークなアイテム ID とインデックスを生成します．
      */
@@ -173,15 +155,16 @@ private:
     const char *file_dir_path_;
     const char *thumb_dir_path_;
 
-    UploadItemWriter item_writer_;
-
     UploadItemList *item_list_;
     ThumbnailList *thumbnail_list_;
-    /** マネージャのロック (in in 共有メモリ) */
+
+    UploadItemWriter item_writer_;
+
+    /** マネージャのロック */
     apr_atomic_t *lock_;
-    /** 最終更新時刻 (in in 共有メモリ) */
+    /** 最終更新時刻 */
     apr_time_t *mtime_;
-    /** 変更カウンタ (in in 共有メモリ) */
+    /** 変更カウンタ */
     apr_size_t *age_;
 };
 
