@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2508 2007-07-06 22:47:18Z svn $
+ * $Id: UploadItemList.cpp 2567 2007-10-10 17:12:24Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2508 2007-07-06 22:47:18Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2567 2007-10-10 17:12:24Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -48,23 +48,6 @@ SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2508 2007-07-06 22:47:18Z svn $");
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-UploadItemList::UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
-                               apr_size_t max_list_size)
-  : header_list_(0),
-    header_list_size_(0),
-    total_file_size_(0),
-    max_file_size_(max_file_size),
-    max_list_size_(max_list_size)
-{
-#ifdef DEBUG
-    if (apr_shm_size_get(shm) != get_memory_size(max_list_size)) {
-        THROW(MESSAGE_SHM_SIZE_INVALID);
-    }
-#endif
-
-    init_shm();
-}
-
 void UploadItemList::add(UploadItem *uitem)
 {
     apr_size_t i;
@@ -79,12 +62,12 @@ void UploadItemList::add(UploadItem *uitem)
         if (header_list_size == max_list_size_) { // 追加する必要なし
             return;
         } else { // 末尾に追加
-            load_header(uitem, header_list_ + header_list_size);
+            load_header(uitem, get_header_list() + header_list_size);
         }
     } else { // 挿入
-        memmove(header_list_ + i + 1, header_list_ + i,
+        memmove(get_header_list() + i + 1, get_header_list() + i,
                 sizeof(UploadItem::header_t) * (header_list_size - i));
-        load_header(uitem, header_list_ + i);
+        load_header(uitem, get_header_list() + i);
     }
 
     total_file_size_ += uitem->get_file_size();
@@ -95,7 +78,7 @@ void UploadItemList::remove(apr_size_t item_id)
 {
     apr_size_t i;
     apr_uint64_t file_size;
-    UploadItem::header_t *header;
+    const UploadItem::header_t *header;
     apr_size_t header_list_size;
 
     header_list_size = size();
@@ -110,7 +93,7 @@ void UploadItemList::remove(apr_size_t item_id)
     file_size = header->file_size;
 
     if (i != (header_list_size - 1)) {
-        memmove(header_list_ + i, header_list_ + i + 1,
+        memmove(get_header_list() + i, get_header_list() + i + 1,
                 sizeof(UploadItem::header_t) * (header_list_size - i - 1));
     }
 
@@ -136,12 +119,7 @@ UploadItemList *UploadItemList::get_instance(apr_shm_t *shm,
 
 UploadItemList *UploadItemList::child_init(apr_shm_t *shm)
 {
-    UploadItemList *item_list;
-
-    item_list = AS_UITEM_LIST(apr_shm_baseaddr_get(shm));
-    item_list->child_init_impl();
-
-    return item_list;
+    return AS_UITEM_LIST(apr_shm_baseaddr_get(shm));
 }
 
 apr_size_t UploadItemList::get_memory_size(apr_size_t max_list_size)
@@ -157,7 +135,7 @@ void UploadItemList::dump_header_list(apr_pool_t *pool,
 
     size = list->size();
     for (apr_size_t i = 0; i < size; i++) {
-        dump_header(pool, list->header_list_ + i);
+        dump_header(pool, list->get_by_index(i));
     }
 }
 
@@ -165,29 +143,18 @@ void UploadItemList::dump_header_list(apr_pool_t *pool,
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-void UploadItemList::child_init_impl()
+UploadItemList::UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
+                               apr_size_t max_list_size)
+  : header_list_size_(0),
+    total_file_size_(0),
+    max_file_size_(max_file_size),
+    max_list_size_(max_list_size)
 {
-    attach_shm();
-}
-
-void UploadItemList::init_shm()
-{
-    header_list_ = AS_UHEADER(this + 1);
-
-#ifdef __INTEL_COMPILER
-#pragma warning(disable:1684)
+#ifdef DEBUG
+    if (apr_shm_size_get(shm) != get_memory_size(max_list_size)) {
+        THROW(MESSAGE_SHM_SIZE_INVALID);
+    }
 #endif
-    ASSERT_EQUAL(AS_CHAR(header_list_ + max_list_size_),
-                 AS_CHAR(header_list_) +
-                 (get_memory_size(max_list_size_) - sizeof(UploadItemList)));
-#ifdef __INTEL_COMPILER
-#pragma warning(default:1684)
-#endif
-}
-
-void UploadItemList::attach_shm()
-{
-    init_shm();
 }
 
 apr_size_t UploadItemList::get_insert_index(UploadItem *uitem) const
@@ -198,7 +165,7 @@ apr_size_t UploadItemList::get_insert_index(UploadItem *uitem) const
     header_list_size = size();
 
     for (i = 0; i < header_list_size; i++) {
-        if (uitem->get_mtime() >= header_list_[i].mtime) {
+        if (uitem->get_mtime() >= get_by_index(i)->mtime) {
             return i;
         }
     }
@@ -213,7 +180,7 @@ apr_size_t UploadItemList::get_index_by_id(apr_size_t item_id) const
 
     // 頻繁には呼ばれ無いはずなので，線形探索...
     for (apr_size_t i = 0; i < header_list_size; i++) {
-        if ((header_list_ + i)->id == item_id) {
+        if (get_by_index(i)->id == item_id) {
             return i;
         }
     }
@@ -228,7 +195,7 @@ void UploadItemList::load_header(UploadItem *uitem,
 }
 
 void UploadItemList::dump_header(apr_pool_t *pool,
-                               UploadItem::header_t *header)
+                                 const UploadItem::header_t *header)
 {
     cerr << setw(10) << static_cast<unsigned int>(header->id) << " ";
     cout << "[" << header->file_name << "] ";
