@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.cpp 2556 2007-08-12 01:36:38Z svn $
+ * $Id: UploadItemListReader.cpp 2564 2007-10-10 14:08:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2556 2007-08-12 01:36:38Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2564 2007-10-10 14:08:20Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -52,10 +52,11 @@ SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2556 2007-08-12 01:36:38Z svn $")
 UploadItemList *UploadItemListReader::read(apr_pool_t *pool,
                                            const char *data_dir_path,
                                            const char *thumb_dir_path,
+                                           apr_uint64_t max_file_size,
+                                           apr_size_t max_list_size,
                                            apr_shm_t *shm,
                                            ThumbnailList *thumbnail_list,
-                                           apr_uint64_t max_file_size,
-                                           apr_size_t max_list_size)
+                                           apr_time_t *mtime)
 {
     UploadItemList *item_list;
     apr_dir_t *dir;
@@ -63,6 +64,8 @@ UploadItemList *UploadItemListReader::read(apr_pool_t *pool,
     char *sub_dir_path;
     TemporaryPool temp_pool(pool);
 
+    *mtime = 0;
+
     UploadItemReader uitem_reader(temp_pool.get(),
                                   data_dir_path, NULL, thumb_dir_path);
 
@@ -79,6 +82,10 @@ UploadItemList *UploadItemListReader::read(apr_pool_t *pool,
             !is_subdir_name_valid(sub_dir_info.name)) {
             continue;
         }
+        if (sub_dir_info.mtime > *mtime) {
+            *mtime = sub_dir_info.mtime;
+        }
+
         if (apr_filepath_merge(&sub_dir_path, data_dir_path,
                                sub_dir_info.name, APR_FILEPATH_NOTABOVEROOT,
                                temp_pool.get()) != APR_SUCCESS) {
