@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2508 2007-07-06 22:47:18Z svn $
+ * $Id: UploadItemManager.cpp 2569 2007-10-12 16:23:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -48,7 +48,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2508 2007-07-06 22:47:18Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2569 2007-10-12 16:23:04Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -75,17 +75,6 @@ const apr_size_t UploadItemManager::SYNC_LIMIT  = 200;
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-void UploadItemManager::init(UploadItemList *item_list,
-                             ThumbnailList *thumbnail_list)
-{
-    clear_shm();
-
-    item_list_ = item_list;
-    thumbnail_list_ = thumbnail_list;
-
-    init_shm();
-}
-
 apr_size_t UploadItemManager::add(apr_pool_t *pool,
                                   const char *file_name, const char *file_mime,
                                   apr_uint64_t file_size,
@@ -177,7 +166,10 @@ UploadItemManager *UploadItemManager::get_instance(apr_shm_t *shm,
                                                    apr_pool_t *pool,
                                                    const char *data_dir_path,
                                                    const char *file_dir_path,
-                                                   const char *thumb_dir_path)
+                                                   const char *thumb_dir_path,
+                                                   UploadItemList *item_list,
+                                                   ThumbnailList *thumbnail_list,
+                                                   apr_time_t mtime)
 {
     UploadItemManager *item_manager;
 
@@ -187,29 +179,39 @@ UploadItemManager *UploadItemManager::get_instance(apr_shm_t *shm,
     }
 #endif
 
-    item_manager = AS_UITEM_MANAGER(apr_shm_baseaddr_get(shm));
-    new(item_manager) UploadItemManager(pool, data_dir_path, file_dir_path,
-                                        thumb_dir_path);
+    APR_PALLOC(item_manager, UploadItemManager *, pool,
+               sizeof(UploadItemManager));
+
+    new(item_manager) UploadItemManager(shm, pool, data_dir_path,
+                                        file_dir_path, thumb_dir_path,
+                                        item_list, thumbnail_list, mtime);
 
     return item_manager;
 }
 
-UploadItemManager *UploadItemManager::child_init(apr_shm_t *shm,
-                                                 UploadItemList *item_list,
-                                                 ThumbnailList *thumbnail_list)
+void UploadItemManager::child_init(apr_shm_t *shm, UploadItemList *item_list,
+                                   ThumbnailList *thumbnail_list)
 {
-    UploadItemManager *item_manager;
+    lock_ = AS_ATOMIC(apr_shm_baseaddr_get(shm));
+    mtime_ = AS_TIME(lock_ + 1);
+    age_ = AS_SIZE(mtime_ + 1);
 
-    item_manager = AS_UITEM_MANAGER(apr_shm_baseaddr_get(shm));
-    item_manager->child_init_impl(item_list, thumbnail_list);
+#ifdef __INTEL_COMPILER
+#pragma warning(disable:1684)
+#endif
+    ASSERT_EQUAL(AS_CHAR(age_ + 1),
+                 AS_CHAR(apr_shm_baseaddr_get(shm)) + get_memory_size());
+#ifdef __INTEL_COMPILER
+#pragma warning(default:1684)
+#endif
 
-    return item_manager;
+    item_list_ = item_list;
+    thumbnail_list_ = thumbnail_list;
 }
 
 apr_size_t UploadItemManager::get_memory_size()
 {
-    return sizeof(UploadItemManager) + sizeof(apr_time_t) +
-        sizeof(apr_atomic_t) + sizeof(apr_size_t);
+    return sizeof(apr_time_t) + sizeof(apr_atomic_t) + sizeof(apr_size_t);
 }
 
 void UploadItemManager::check_finalize_state(UploadItemManager *item_manager)
@@ -223,17 +225,24 @@ void UploadItemManager::check_finalize_state(UploadItemManager *item_manager)
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-UploadItemManager::UploadItemManager(apr_pool_t *pool,
+UploadItemManager::UploadItemManager(apr_shm_t *shm, apr_pool_t *pool,
                                      const char *data_dir_path,
                                      const char *file_dir_path,
-                                     const char *thumb_dir_path)
+                                     const char *thumb_dir_path,
+                                     UploadItemList *item_list,
+                                     ThumbnailList *thumbnail_list,
+                                     apr_time_t mtime)
   : pool_(pool),
     data_dir_path_(data_dir_path),
     file_dir_path_(file_dir_path),
     thumb_dir_path_(thumb_dir_path),
-    item_writer_(pool_, data_dir_path, file_dir_path, thumb_dir_path)
+    item_writer_(pool, data_dir_path, file_dir_path, thumb_dir_path)
 {
+    child_init(shm, item_list, thumbnail_list);
 
+    *lock_ = 0;
+    *mtime_ = mtime;
+    *age_ = 0;
 }
 
 apr_size_t UploadItemManager::add_impl(apr_pool_t *pool,
@@ -298,42 +307,6 @@ void UploadItemManager::remove_impl(apr_pool_t *pool, UploadItem *uitem)
     *mtime_ = apr_time_now();
 }
 
-void UploadItemManager::child_init_impl(UploadItemList *item_list,
-                                        ThumbnailList *thumbnail_list)
-{
-    item_list_ = item_list;
-    thumbnail_list_ = thumbnail_list;
-
-    attach_shm();
-}
-
-void UploadItemManager::clear_shm()
-{
-    memset(this + 1, 0, get_memory_size() - sizeof(UploadItemManager));
-}
-
-void UploadItemManager::init_shm()
-{
-    lock_ = AS_ATOMIC(this + 1);
-    mtime_ = AS_TIME(lock_ + 1);
-    age_ = AS_SIZE(mtime_ + 1);
-
-#ifdef __INTEL_COMPILER
-#pragma warning(disable:1684)
-#endif
-    ASSERT_EQUAL(AS_CHAR(age_ + 1),
-                 AS_CHAR(lock_) +
-                 (get_memory_size() - sizeof(UploadItemManager)));
-#ifdef __INTEL_COMPILER
-#pragma warning(default:1684)
-#endif
-}
-
-void UploadItemManager::attach_shm()
-{
-    init_shm();
-}
-
 void UploadItemManager::create_item_id_index(apr_size_t *item_id,
                                              apr_size_t *item_index) const
 {
