@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2423 2007-05-13 14:54:19Z svn $
+ * $Id: UploaderConfig.cpp 2568 2007-10-11 15:47:19Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -46,7 +46,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2423 2007-05-13 14:54:19Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2568 2007-10-11 15:47:19Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -146,6 +146,8 @@ UploaderConfig::UploaderConfig(apr_pool_t *pool)
 
 void UploaderConfig::init()
 {
+    apr_time_t mtime;
+
     if (is_active_) {
         return;
     }
@@ -171,16 +173,14 @@ void UploaderConfig::init()
 
     thumbnail_list_ = ThumbnailList::get_instance(thumbnail_list_shm_,
                                                   total_file_number_limit);
-    item_list_ = UploadItemListReader::read(pool_, data_dir_path,
-                                            thumb_dir_path, item_list_shm_,
-                                            thumbnail_list_,
-                                            total_file_size_limit,
-                                            total_file_number_limit);
-    item_manager_ = UploadItemManager::get_instance(item_manager_shm_, pool_,
-                                                    data_dir_path,
-                                                    file_dir_path,
-                                                    thumb_dir_path);
-    item_manager_->init(item_list_, thumbnail_list_);
+    item_list_ = UploadItemListReader::read
+        (pool_, data_dir_path, thumb_dir_path,
+         total_file_size_limit, total_file_number_limit,
+         item_list_shm_, thumbnail_list_, &mtime);
+    item_manager_ = UploadItemManager::get_instance
+        (item_manager_shm_, pool_,
+         data_dir_path, file_dir_path, thumb_dir_path,
+         item_list_, thumbnail_list_, mtime);
 
     download_flow_controller_ = DownloadFlowController::get_instance
         (download_flow_controller_shm_);
@@ -207,8 +207,7 @@ void UploaderConfig::child_init()
 
     item_list_ = UploadItemList::child_init(item_list_shm_);
     thumbnail_list_ = ThumbnailList::child_init(thumbnail_list_shm_);
-    item_manager_ = UploadItemManager::child_init(item_manager_shm_,
-                                                  item_list_, thumbnail_list_);
+    item_manager_->child_init(item_manager_shm_, item_list_, thumbnail_list_);
 }
 
 void UploaderConfig::finalize()
